@@ -5,11 +5,12 @@
 #ifndef _SSPOP_H
 #define _SSPOP_H
 
-#import <objectbase.h>
+#import <objectbase/Swarm.h>
 
 #import "Population.h"		// Population protocol
 
-@interface PopulationSwarm: Swarm <Population> { // Steady state population
+@interface PopulationSwarm: Swarm <Population> // Steady state population
+{
   // Simulation parameters
   unsigned initPopSize, popSize;
   float mating, mut, 
